Documentation
¶
Index ¶
Constants ¶
const (
InputFilePath = "/file.yaml"
)
Variables ¶
This section is empty.
Functions ¶
func CommonExcludedFileArgs ¶
func CommonExcludedFileArgs() []string
func TimeBubbleStartTime ¶
Types ¶
type NewRootCmdFunc ¶
NewRootCmdFunc returns the root command for the cli and an output buffer which returns the output after command execution
func NewRootCmd ¶
func NewRootCmd(t *testing.T, c *TestConfig) NewRootCmdFunc
type Test ¶
type Test[Response, RawObject any] struct { Name string NewRootCmd NewRootCmdFunc CmdArgs []string Out *bytes.Buffer AssertExhaustiveArgs bool AssertExhaustiveExcludes []string // output format tests WantObject RawObject // for rawyaml / rawjson printer WantProtoObject proto.Message // for yaml / json printer WantTable *string // for table printer WantWideTable *string // for wide table printer WantMarkdown *string // for markdown printer WantTemplate *string // for template printer Template *string // for template printer WantErr error }
type TestConfig ¶
Click to show internal directories.
Click to hide internal directories.